<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP" sourcelanguage="en">
<context>
    <name>About</name>
    <message>
        <location filename="../../src/about.ui" line="17"/>
        <source>About KDiskMark</source>
        <translation>KDiskMark について</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="62"/>
        <source>Version:</source>
        <translation>バージョン:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="88"/>
        <source>License:</source>
        <translation>ライセンス:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="114"/>
        <source>Author:</source>
        <translation>作者:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="146"/>
        <source>E-mail:</source>
        <translation>E-mail:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="178"/>
        <source>Flexible I/O Tester:</source>
        <translation>柔軟な I/O テスター:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="204"/>
        <source>Application Icon:</source>
        <translation>アプリアイコン:</translation>
    </message>
</context>
<context>
    <name>Benchmark</name>
    <message>
        <location filename="../../src/benchmark.cpp" line="232"/>
        <source>Preparing...</source>
        <translation>準備中...</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="254"/>
        <source>Sequential Read %1/%2</source>
        <translation>Sequential Read %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="258"/>
        <source>Random Read %1/%2</source>
        <translation>Random Read %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="264"/>
        <source>Sequential Write %1/%2</source>
        <translation>Sequential Write %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="268"/>
        <source>Random Write %1/%2</source>
        <translation>Random Write %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="274"/>
        <source>Sequential Mix %1/%2</source>
        <translation>Sequential Mix %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="278"/>
        <source>Random Mix %1/%2</source>
        <translation>Random Mix %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="285"/>
        <source>Interval Time %1/%2 sec</source>
        <translation>インターバル %1/%2 sec</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="405"/>
        <source>Could not obtain administrator privileges.</source>
        <translation>管理者権限を取得できませんでした。</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/mainwindow.ui" line="30"/>
        <location filename="../../src/mainwindow.cpp" line="917"/>
        <source>All</source>
        <translation>All</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="220"/>
        <location filename="../../src/mainwindow.cpp" line="436"/>
        <location filename="../../src/mainwindow.cpp" line="440"/>
        <source>MB/s</source>
        <translation>MB/s</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="225"/>
        <source>GB/s</source>
        <translation>GB/s</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="230"/>
        <location filename="../../src/mainwindow.cpp" line="442"/>
        <location filename="../../src/mainwindow.cpp" line="443"/>
        <source>IOPS</source>
        <translation>IOPS</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="235"/>
        <location filename="../../src/mainwindow.cpp" line="445"/>
        <location filename="../../src/mainwindow.cpp" line="446"/>
        <source>μs</source>
        <translation>μs</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="351"/>
        <location filename="../../src/mainwindow.ui" line="933"/>
        <location filename="../../src/mainwindow.cpp" line="547"/>
        <source>Read</source>
        <translation>Read</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="520"/>
        <location filename="../../src/mainwindow.ui" line="952"/>
        <location filename="../../src/mainwindow.cpp" line="550"/>
        <source>Write</source>
        <translation>Write</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="686"/>
        <location filename="../../src/mainwindow.cpp" line="553"/>
        <source>Mix</source>
        <translation>Mix</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1017"/>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1025"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1029"/>
        <source>Test Data</source>
        <translation>テストデータ</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1047"/>
        <source>Profile</source>
        <translation>プロファイル</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1063"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1067"/>
        <source>Language</source>
        <translation>言語</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1075"/>
        <source>Theme</source>
        <translation>テーマ</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1091"/>
        <source>About KDiskMark</source>
        <translation>KDiskMark について</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1096"/>
        <source>Queues &amp;&amp; Threads</source>
        <translation>キュー数 &amp;&amp; スレッド数</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1101"/>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1106"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1111"/>
        <source>Exit</source>
        <translation>終了</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1122"/>
        <source>Default</source>
        <translation>デフォルト</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1130"/>
        <source>Peak Performance</source>
        <translation>ピーク性能</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1138"/>
        <source>Real World Performance</source>
        <translation>現実性能</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1146"/>
        <source>Default [+Mix]</source>
        <translation>デフォルト [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1154"/>
        <source>Peak Performance [+Mix]</source>
        <translation>ピーク性能 [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1162"/>
        <source>Real World Performance [+Mix]</source>
        <translation>現実性能 [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1173"/>
        <source>Flush Pagecache</source>
        <translation>ページキャッシュをフラッシュ</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1181"/>
        <source>Demo</source>
        <translation>デモ</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1192"/>
        <source>Read and Write [+Mix]</source>
        <translation>Read and Write [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1200"/>
        <source>Read [+Mix]</source>
        <translation>Read [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1208"/>
        <source>Write [+Mix]</source>
        <translation>Write [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1219"/>
        <source>Random</source>
        <translation>ランダム</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1227"/>
        <source>Fill with zeros</source>
        <translation>All 0x00 (0Fill)</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1238"/>
        <source>Standard Preset</source>
        <translation>標準プリセット</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1246"/>
        <source>NVMe SSD</source>
        <translation>NVMe SSD</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1257"/>
        <source>Use Fusion</source>
        <translation>Fusion</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1265"/>
        <source>Stylesheet Light</source>
        <translation>ライト用スタイルシート</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1273"/>
        <source>Stylesheet Dark</source>
        <translation>ダーク用スタイルシート</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1281"/>
        <source>Do not apply</source>
        <translation>適用しない</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1292"/>
        <source>Use O_DIRECT</source>
        <translation>O_DIRECT を使用</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1303"/>
        <source>CoW detection</source>
        <translation>CoW検出</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="54"/>
        <source>The device is encrypted. Performance may drop.</source>
        <translation>デバイスが暗号化されています。性能が低下する場合があります。</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="263"/>
        <location filename="../../src/mainwindow.cpp" line="322"/>
        <source>Add a directory</source>
        <translation>ディレクトリを追加</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="352"/>
        <location filename="../../src/mainwindow.cpp" line="452"/>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="356"/>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="452"/>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>PiB</source>
        <translation>PiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="892"/>
        <location filename="../../src/mainwindow.cpp" line="893"/>
        <location filename="../../src/mainwindow.cpp" line="894"/>
        <location filename="../../src/mainwindow.cpp" line="895"/>
        <location filename="../../src/mainwindow.cpp" line="896"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="944"/>
        <source>Stopping...</source>
        <translation>Stopping...</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="954"/>
        <source>Not available</source>
        <translation>利用できません</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="954"/>
        <source>Directory is not specified.</source>
        <translation>ディレクトリが指定されていません。</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="1059"/>
        <source>Copy-on-Write (CoW) is enabled on the selected directory.</source>
        <translation>選択されたディレクトリで書き込み時コピー（CoW）が有効になっています。</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="1060"/>
        <source>This may affect performance results. Would you like to create a new subdirectory with CoW disabled?</source>
        <translation>これはパフォーマンスの結果に影響を与える可能性があります。CoWを無効にした新しいサブディレクトリを作成しますか？</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation type="vanished">確認</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="964"/>
        <source>Benchmark Failed</source>
        <translation>ベンチマーク失敗</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/global.cpp" line="25"/>
        <source>&lt;h2&gt;%1 %2 %3&lt;br/&gt;Queues=%4&lt;br/&gt;Threads=%5%6&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;%1 %2 %3&lt;br/&gt;Queues=%4&lt;br/&gt;Threads=%5%6&lt;/h2&gt;</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="26"/>
        <source>Sequential</source>
        <translation>Sequential</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="26"/>
        <source>Random</source>
        <translation>Random</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="28"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="28"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="34"/>
        <source>&lt;h1&gt;%1 MB/s&lt;br/&gt;%2 GB/s&lt;br/&gt;%3 IOPS&lt;br/&gt;%4 μs&lt;/h1&gt;</source>
        <translation>&lt;h1&gt;%1 MB/s&lt;br/&gt;%2 GB/s&lt;br/&gt;%3 IOPS&lt;br/&gt;%4 μs&lt;/h1&gt;</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="200"/>
        <source>No FIO was found. Please install FIO before using KDiskMark.</source>
        <translation>FIO が見つかりませんでした。KDiskMark を使用する前に FIO をインストールしてください。</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../../src/settings.ui" line="14"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="149"/>
        <source>Block Size</source>
        <translation>ブロックサイズ</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="165"/>
        <source>Queues</source>
        <translation>キュー数</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="181"/>
        <source>Threads</source>
        <translation>スレッド数</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="257"/>
        <source>Profile: Default</source>
        <translation>プロファイル: デフォルト</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="280"/>
        <source>Type</source>
        <translation>タイプ</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="335"/>
        <source>Profile: Peak Performance</source>
        <translation>プロファイル: ピーク性能</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="446"/>
        <source>Profile: Demo</source>
        <translation>プロファイル: デモ</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="508"/>
        <source>Measuring time</source>
        <translation>測定時間</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="530"/>
        <source>Interval time</source>
        <translation>測定間隔</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="18"/>
        <location filename="../../src/settings.cpp" line="23"/>
        <source>sec</source>
        <translation>sec</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="19"/>
        <location filename="../../src/settings.cpp" line="24"/>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="59"/>
        <location filename="../../src/settings.cpp" line="60"/>
        <location filename="../../src/settings.cpp" line="61"/>
        <location filename="../../src/settings.cpp" line="62"/>
        <location filename="../../src/settings.cpp" line="64"/>
        <location filename="../../src/settings.cpp" line="65"/>
        <location filename="../../src/settings.cpp" line="67"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="71"/>
        <location filename="../../src/settings.cpp" line="72"/>
        <location filename="../../src/settings.cpp" line="73"/>
        <location filename="../../src/settings.cpp" line="74"/>
        <location filename="../../src/settings.cpp" line="76"/>
        <location filename="../../src/settings.cpp" line="77"/>
        <location filename="../../src/settings.cpp" line="79"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
</context>
</TS>
